@@ -1,4 +1,4 @@
-# $Id: Tree.pm 1296 2010-05-10 16:18:34Z rvos $
+# $Id: Tree.pm 1469 2010-11-12 23:13:55Z rvos $
 package Bio::Phylo::Forest::Tree;
 use strict;
 use Bio::Phylo::Listable ();
@@ -2305,30 +2305,6 @@ Serializes invocant to SVG.
 	    return $drawer->draw;
 	}
 
-=item to_json()
-
-Serializes object to JSON string
-
- Type    : Serializer
- Title   : to_json()
- Usage   : print $obj->to_json();
- Function: Serializes object to JSON string
- Returns : String 
- Args    : None
- Comments:
-
-=cut
-
-    sub to_json {
-        my $self = shift;
-        if ( my $root = $self->get_root ) {
-            return '{' . $self->_to_json() . ',"root":' . $root->to_json() . '}';
-        }
-        else {
-            return $self->SUPER::to_json;
-        }
-    }
-
 =item to_dom()
 
  Type    : Serializer
@@ -2461,7 +2437,7 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =head1 REVISION
 
- $Id: Tree.pm 1296 2010-05-10 16:18:34Z rvos $
+ $Id: Tree.pm 1469 2010-11-12 23:13:55Z rvos $
 
 =cut
 
