@@ -1,8 +1,8 @@
-# $Id: Newick.pm 843 2009-03-04 23:50:27Z rvos $
+# $Id: Newick.pm 1235 2010-03-02 16:11:07Z rvos $
 package Bio::Phylo::Parsers::Newick;
 use strict;
-use Bio::Phylo::IO;
-use Bio::Phylo;
+use Bio::Phylo::IO ();
+use Bio::Phylo ();
 use Bio::Phylo::Factory;
 use vars qw(@ISA);
 @ISA=qw(Bio::Phylo::IO);
@@ -428,7 +428,7 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =head1 REVISION
 
- $Id: Newick.pm 843 2009-03-04 23:50:27Z rvos $
+ $Id: Newick.pm 1235 2010-03-02 16:11:07Z rvos $
 
 =cut
 
